@@ -1,7 +1,7 @@
 # Authors:  David Goodger; Garth Kidd
 # Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 1.55 $
-# Date: $Date: 2004/11/01 02:58:09 $
+# Revision: $Revision: 3268 $
+# Date: $Date: 2005-04-27 23:04:03 +0200 (Wed, 27 Apr 2005) $
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -167,6 +167,9 @@ class CustomTestCase(unittest.TestCase):
             raise self.failureException, \
                   (msg or '%s == %s' % _format_str(first, second))
 
+    def setUp(self):
+        os.chdir(testroot)
+
     # Synonyms for assertion methods
 
     assertEqual = assertEquals = failUnlessEqual
@@ -728,22 +731,37 @@ class HtmlWriterPublishPartsTestCase(WriterPublishTestCase):
         expected = self.expected % {'version': docutils.__version__}
         self.compare_output(self.input, output, expected)
 
-    standard_meta_value = """\
-<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-<meta name="generator" content="Docutils %s: http://docutils.sourceforge.net/" />
-""" % docutils.__version__
+    
+    standard_content_type_template = ('<meta http-equiv="Content-Type"'
+                                      ' content="text/html; charset=%s" />\n')
+    standard_generator_template = (
+        '<meta name="generator"'
+        ' content="Docutils %s: http://docutils.sourceforge.net/" />\n')
+    standard_html_meta_value = (
+        standard_content_type_template
+        + standard_generator_template % docutils.__version__)
+    standard_meta_value = standard_html_meta_value % 'utf-8'
     standard_stylesheet_value = ('<link rel="stylesheet" href="default.css" '
                                  'type="text/css" />\n')
+    standard_html_prolog = """\
+<?xml version="1.0" encoding="%s" ?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+"""
 
     def format_output(self, parts):
         """Minimize & standardize the output."""
-        # remove redundant bits:
+        # remove redundant parts:
         del parts['whole']
+        assert parts['body'] == parts['fragment']
         del parts['body']
-        # remove standard bits:
+        # remove standard portions:
         parts['meta'] = parts['meta'].replace(self.standard_meta_value, '')
         if parts['stylesheet'] == self.standard_stylesheet_value:
             del parts['stylesheet']
+        parts['html_head'] = parts['html_head'].replace(
+            self.standard_html_meta_value, '...')
+        parts['html_prolog'] = parts['html_prolog'].replace(
+            self.standard_html_prolog, '')
         # remove empty values:
         for key in parts.keys():
             if not parts[key]:
@@ -804,7 +822,7 @@ def _format_str(*args):
                 r = r[1:]
             # quote_char = "'" or '"'
             quote_char = r[0]
-            assert quote_char in ("'", "'")
+            assert quote_char in ("'", '"')
             assert r[0] == r[-1]
             r = r[1:-1]
             r = (stripped + 3 * quote_char + '\\\n' +
