@@ -1,11 +1,12 @@
+execfile('functional/tests/_standalone_rst_defaults.py')
+
 # Source and destination file names.
 test_source = "standalone_rst_html4css1.txt"
 test_destination = "standalone_rst_html4css1.html"
 
 # Keyword parameters passed to publish_file.
-reader_name = "standalone"
-parser_name = "rst"
 writer_name = "html4css1"
 
-# Settings
+# Settings.
+settings_overrides['stylesheet'] = None
 settings_overrides['stylesheet_path'] = "../tools/stylesheets/default.css"
