@@ -2,8 +2,8 @@
 
 # Author: Felix Wiemann
 # Contact: Felix_Wiemann@ososo.de
-# Revision: $Revision: 1.8 $
-# Date: $Date: 2004/10/05 01:22:15 $
+# Revision: $Revision: 3176 $
+# Date: $Date: 2005-04-06 17:43:49 +0200 (Wed, 06 Apr 2005) $
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -112,14 +112,16 @@ class FunctionalTestCase(DocutilsTestSupport.CustomTestCase):
         # Get the expected output *after* writing the actual output.
         self.assert_(os.access(expected_path, os.R_OK),\
                      'Cannot find expected output at\n' + expected_path)
-        expected = open(expected_path).read()
+        f = open(expected_path, 'rU')
+        expected = f.read()
+        f.close()
         diff = ('The expected and actual output differs.\n'
                 'Please compare the expected and actual output files:\n'
                 '  diff %s %s\n'
                 'If the actual output is correct, please replace the\n'
-                'expected output and check it in to CVS:\n'
+                'expected output and check it in to Subversion:\n'
                 '  mv %s %s\n'
-                '  cvs commit -m "<comment>" %s'
+                '  svn commit -m "<comment>" %s'
                 % (expected_path, params['destination_path'],
                    params['destination_path'], expected_path, expected_path))
         try:
