@@ -2,8 +2,8 @@
 
 # Author: David Goodger
 # Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 1.11 $
-# Date: $Date: 2003/07/05 19:43:13 $
+# Revision: $Revision: 3160 $
+# Date: $Date: 2005-04-03 01:12:06 +0200 (Sun, 03 Apr 2005) $
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -11,6 +11,7 @@ Tests for misc.py "include" directive.
 """
 
 import os.path
+import sys
 from __init__ import DocutilsTestSupport
 
 
@@ -19,7 +20,7 @@ def suite():
     s.generateTests(totest)
     return s
 
-mydir = os.path.dirname(suite.func_code.co_filename)
+mydir = 'test_parsers/test_rst/test_directives/'
 include1 = os.path.join(mydir, 'include1.txt')
 include1rel = DocutilsTestSupport.utils.relative_path(None, include1)
 include2 = os.path.join(mydir, 'include2.txt')
@@ -27,6 +28,10 @@ include3 = os.path.join(mydir, 'include3.txt')
 include8 = os.path.join(mydir, 'include8.txt')
 include10 = os.path.join(mydir, 'include10.txt')
 include10rel = DocutilsTestSupport.utils.relative_path(None, include10)
+include11 = os.path.join(mydir, 'include 11.txt')
+include11rel = DocutilsTestSupport.utils.relative_path(None, include11)
+utf_16_file = os.path.join(mydir, 'utf-16.csv')
+utf_16_file_rel = DocutilsTestSupport.utils.relative_path(None, utf_16_file)
 
 
 totest = {}
@@ -42,10 +47,10 @@ A paragraph.
 """ % include1,
 """\
 <document source="test data">
-    <section id="include-test" name="include test">
+    <section ids="include-test" names="include test">
         <title>
             Include Test
-        <section id="inclusion-1" name="inclusion 1">
+        <section ids="inclusion-1" names="inclusion 1">
             <title>
                 Inclusion 1
             <paragraph>
@@ -67,7 +72,7 @@ A paragraph.
 """ % include1,
 """\
 <document source="test data">
-    <section id="include-test" name="include test">
+    <section ids="include-test" names="include test">
         <title>
             Include Test
         <literal_block source="%s" xml:space="preserve">
@@ -115,7 +120,7 @@ A paragraph.
 """,
 """\
 <document source="test data">
-    <section id="include-test" name="include test">
+    <section ids="include-test" names="include test">
         <title>
             Include Test
         <system_message level="4" line="4" source="test data" type="SEVERE">
@@ -139,10 +144,10 @@ A paragraph.
 """ % (include1, include1),
 """\
 <document source="test data">
-    <section id="include-test" name="include test">
+    <section ids="include-test" names="include test">
         <title>
             Include Test
-        <section dupname="inclusion 1" id="inclusion-1">
+        <section dupnames="inclusion 1" ids="inclusion-1">
             <title>
                 Inclusion 1
             <paragraph>
@@ -150,7 +155,7 @@ A paragraph.
                 <literal>
                     test_include.py
                 .
-        <section dupname="inclusion 1" id="id1">
+        <section dupnames="inclusion 1" ids="id1">
             <title>
                 Inclusion 1
             <system_message backrefs="id1" level="1" line="2" source="%s" type="INFO">
@@ -178,29 +183,26 @@ A paragraph.
 """ % (include1, include1),
 """\
 <document source="test data">
-    <section id="include-test" name="include test">
+    <section ids="include-test" names="include test">
         <title>
             Include Test
-        <section dupname="inclusion 1" id="inclusion-1">
+        <section dupnames="inclusion 1" ids="inclusion-1">
             <title>
                 Inclusion 1
             <paragraph>
-                This file is used by 
+                This file is used by \n\
                 <literal>
                     test_include.py
                 .
             <transition>
-            <system_message level="3" line="12" source="test data" type="ERROR">
-                <paragraph>
-                    Section may not end with a transition.
-        <section dupname="inclusion 1" id="id1">
+        <section dupnames="inclusion 1" ids="id1">
             <title>
                 Inclusion 1
             <system_message backrefs="id1" level="1" line="2" source="%s" type="INFO">
                 <paragraph>
                     Duplicate implicit target name: "inclusion 1".
             <paragraph>
-                This file is used by 
+                This file is used by \n\
                 <literal>
                     test_include.py
                 .
@@ -241,7 +243,7 @@ Section
 <document source="test data">
     <paragraph>
         In test data
-    <section id="section" name="section">
+    <section ids="section" names="section">
         <title>
             Section
         <paragraph>
@@ -279,6 +281,42 @@ Testing relative includes:
             test_include.py
         .
 """],
+["""\
+Encoding:
+
+.. include:: %s
+   :encoding: utf-16
+""" % utf_16_file_rel,
+u"""\
+<document source="test data">
+    <paragraph>
+        Encoding:
+    <paragraph>
+        "Treat", "Quantity", "Description"
+        "Albatr\xb0\xdf", 2.99, "\xa1On a \\u03c3\\u03c4\\u03b9\\u03ba!"
+        "Crunchy Frog", 1.49, "If we took the b\xf6nes out, it wouldn\\u2019t be
+        crunchy, now would it?"
+        "Gannet Ripple", 1.99, "\xbfOn a \\u03c3\\u03c4\\u03b9\\u03ba?"
+"""],
+["""\
+Include file is UTF-16-encoded, and is not valid ASCII.
+
+.. include:: %s
+   :encoding: ascii
+""" % utf_16_file_rel,
+"""\
+<document source="test data">
+    <paragraph>
+        Include file is UTF-16-encoded, and is not valid ASCII.
+    <system_message level="4" line="3" source="test data" type="SEVERE">
+        <paragraph>
+            Problem with "include" directive:
+            UnicodeError: Unable to decode input data.  Tried the following encodings: 'ascii'.
+            (UnicodeDecodeError: 'ascii' codec can't decode byte 0xfe in position 0: ordinal not in range(128))
+        <literal_block xml:space="preserve">
+            .. include:: %s
+               :encoding: ascii
+""" % utf_16_file_rel],
 # @@@ BUG with errors reported with incorrect "source" & "line":
 # ["""\
 # Testing bad charent includes:
@@ -301,9 +339,33 @@ Testing relative includes:
 #         <literal_block xml:space="preserve">
 #             .. |bad| unicode:: 0xFFFFFFFFF
 # """ % (include10rel, include10rel)],
+["""\
+Include file with whitespace in the path:
+
+.. include:: %s
+""" % include11rel,
+"""\
+<document source="test data">
+    <paragraph>
+        Include file with whitespace in the path:
+    <paragraph>
+        some text
+"""],
 ]
 
 
+# Skip tests whose output contains "UnicodeDecodeError" if we are not
+# using Python 2.3 or higher.
+if sys.version_info < (2, 3):
+    for i in range(len(totest['include'])):
+        if totest['include'][i][1].find('UnicodeDecodeError') != -1:
+            del totest['include'][i]
+            print ("Test totest['include'][%s] skipped; "
+                   "Python 2.3+ required for expected output." % i)
+            # Assume we have only one of these tests.
+            break
+
+
 if __name__ == '__main__':
     import unittest
     unittest.main(defaultTest='suite')
