@@ -2,8 +2,8 @@
 
 # Author: engelbert gruber
 # Contact: grubert@users.sourceforge.net
-# Revision: $Revision: 1.29 $
-# Date: $Date: 2004/07/29 00:24:32 $
+# Revision: $Revision: 3085 $
+# Date: $Date: 2005-03-22 21:38:43 +0100 (Tue, 22 Mar 2005) $
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -21,6 +21,8 @@ def suite():
 latex_head = """\
 \\documentclass[10pt,a4paper,english]{article}
 \\usepackage{babel}
+\\usepackage{ae}
+\\usepackage{aeguill}
 \\usepackage{shortvrb}
 \\usepackage[latin1]{inputenc}
 \\usepackage{tabularx}
@@ -49,6 +51,16 @@ latex_head = """\
    \\addtolength{\\leftmargin}{\\labelsep}
    \\renewcommand{\\makelabel}{\\optionlistlabel}}
 }{\\end{list}}
+\\newlength{\\lineblockindentation}
+\\setlength{\\lineblockindentation}{2.5em}
+\\newenvironment{lineblock}[1]
+{\\begin{list}{}
+  {\\setlength{\\partopsep}{\\parskip}
+   \\addtolength{\\partopsep}{\\baselineskip}
+   \\topsep0pt\\itemsep0.15\\baselineskip\\parsep0pt
+   \\leftmargin#1}
+ \\raggedright}
+{\\end{list}}
 % begin: floats for footnotes tweaking.
 \\setlength{\\floatsep}{0.5em}
 \\setlength{\\textfloatsep}{\\fill}
@@ -92,7 +104,7 @@ latex_head + """\
 \\setlength{\\locallinewidth}{\\linewidth}
 \\hypertarget{table-of-contents}{}
 \\pdfbookmark[0]{Table of Contents}{table-of-contents}
-\\subsection*{~\\hfill Table of Contents\\hfill ~}
+\\subsubsection*{~\\hfill Table of Contents\\hfill ~}
 \\begin{list}{}{}
 \\item {} \\href{\\#title-1}{Title 1}
 \\begin{list}{}{}
@@ -248,9 +260,9 @@ Inside literal blocks quotes should be left untouched
 (use only two quotes in test code makes life easier for
 the python interpreter running the test):
 \\begin{quote}{\\ttfamily \\raggedright \\noindent
-""~\\\\
+"{}"~\\\\
 This~is~left~"untouched"~also~*this*.~\\\\
-""
+"{}"
 }\\end{quote}
 \\begin{quote}{\\ttfamily \\raggedright \\noindent
 should~get~"quotes"~and~\\emph{italics}.
@@ -327,6 +339,39 @@ the~empty~line~gets~tested~too~\\\\
 """],
 ]
 
+totest['raw'] = [
+["""\
+.. raw:: latex
+
+   \\noindent
+
+A paragraph.
+
+.. |sub| raw:: latex
+
+   (some raw text)
+
+Foo |sub|
+same paragraph.
+""",
+latex_head + """\
+\\title{}
+\\author{}
+\\date{}
+\\raggedbottom
+\\begin{document}
+
+\\setlength{\\locallinewidth}{\\linewidth}
+\\noindent
+A paragraph.
+
+Foo (some raw text)
+same paragraph.
+
+\\end{document}
+"""],
+]
+
 if __name__ == '__main__':
     import unittest
     unittest.main(defaultTest='suite')
